==========
Structures
==========

.. automodule:: elli.structure

Layers
------

Abstract base classes
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: elli.structure.AbstractLayer
    :members:

.. autoclass:: elli.structure.InhomogeneousLayer
    :members:

Homogeneous layers
~~~~~~~~~~~~~~~~~~

.. autoclass:: elli.structure.Layer
    :members:

.. autoclass:: elli.structure.RepeatedLayers
    :members:

Inhomogeneous layers
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: elli.structure.TwistedLayer
    :members:

.. autoclass:: elli.structure.VaryingMixtureLayer
    :members:

Structure Class
---------------

.. autoclass:: elli.structure.Structure
    :members:
